RequestCanceledException class

An exception caused by canceling the request.

Implemented types

Constructors

RequestCanceledException(String? reason, Uri uri)
Create new request cancelled exception.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
reason String?
Reason caused the request to be canceled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri?
The URL of the HTTP request or response that failed.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited